Crate clerk

Clerk

Clerk is a generic and hardware agnostic libary to controll HD44780 compliant LCD displays. Its main goal is to provide all features defined in the HD44780 spec.

Structs

Enums

Traits

  • The Delay trait is used to adapt the timing to the specific hardware and must be implemented by the libary user.
  • The DisplayHardwareLayer trait is intended to be implemented by the library user as a thin wrapper around the hardware specific system calls.
  • This trait is used to specify the start address of the display data RAM.
  • This trait is used to provide an initialization implementation for a [Display] connection. [Display]: struct.Display.html
  • This trait is used to provide an implementation for receiving data via a [Display] connection. [Display]: struct.Display.html
  • This trait is used to provide an implementation for sending data via a [Display] connection. [Display]: struct.Display.html