Clerk
Clerk is a generic and hardware agnostic libary to controll HD44780 compliant LCD displays. Its main goal is to provide all features defined in the HD44780 spec.
Structs
- Four data lines pin wiring setup.
- Eight data lines pin wiring setup.
- A HD44780 compliant display.
- A struct for creating display control settings.
- A struct for creating display entry mode settings.
- A struct for creating display function settings.
- The parallel connection mode is the most common wiring mode for HD44780 compliant displays. It can be used with either four (
DataPins4Lines) or eight (DataPins8Lines) data lines. - This struct is used for easily setting up
ParallelConnections.
Enums
- Sets cursor blinking.
- State of a cursor.
- Enumeration of default lines.
- Enumeration of possible data directions of a pin.
- State of a display.
- Enumeration of possible levels of a pin.
- Enumeration to set display line number.
- Enumeration possible read operations.
- Enumeration of possible methods to seek within a
Displayobject. - Enumeration of possible methods to shift a cursor or display.
- Enumeration possible write operations.
Traits
- The
Delaytrait is used to adapt the timing to the specific hardware and must be implemented by the libary user. - The
DisplayHardwareLayertrait is intended to be implemented by the library user as a thin wrapper around the hardware specific system calls. - This trait is used to specify the start address of the display data RAM.
- This trait is used to provide an initialization implementation for a [
Display] connection. [Display]: struct.Display.html - This trait is used to provide an implementation for receiving data via a [
Display] connection. [Display]: struct.Display.html - This trait is used to provide an implementation for sending data via a [
Display] connection. [Display]: struct.Display.html